<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'occitan (gascon) [oc_gsc]',
'0_liste' => 'lenga.occitana@aprene.org',
'0_mainteneur' => 'Domergue:&nbsp;lenga.occitana@aprene.org ',

// A
'access_interface_graphique' => 'Tornar a l\'interf&agrave;cia grafica completa',
'access_mode_texte' => 'Afichar l\'interf&agrave;cia textuau simplificada',
'admin_debug' => 'desbugatge',
'admin_modifier_article' => 'Modificar aqueth article',
'admin_modifier_auteur' => 'Modificar aqueth autor',
'admin_modifier_breve' => 'Modificar aquera br&egrave;va',
'admin_modifier_mot' => 'Modificar aqueth mot clau',
'admin_modifier_rubrique' => 'Modificar aquera rubrica',
'admin_recalculer' => 'Tornar calcular la pagina',
'afficher_trad' => 'afficher les traductions', # NEW
'alerte_maj_impossible' => '<b>Al&egrave;rta!</b> Qu\'ei impossible d\'actualizar la basa SQL de cap t&agrave; la version @version@; dilh&egrave;u que i a un probl&egrave;ma relatiu au dret de modificar la basa de dadas. Volhatz contactar lo v&ograve;ste aubergader.',
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute;e par ailleurs. La valeur actuelle est&nbsp;:', # NEW
'analyse_xml' => 'Analisi XML',
'annuler' => 'Annuler', # NEW
'antispam_champ_vide' => 'Veuillez laisser ce champ vide&nbsp;:', # NEW
'articles_recents' => 'Los articles mei recents',
'avis_archive_incorrect' => 'lo fichi&egrave;r archiu n\'ei pas un fichi&egrave;r SPIP',
'avis_archive_invalide' => 'lo fichi&egrave;r archiu n\'ei pas valid',
'avis_attention' => 'ATENCION!',
'avis_champ_incorrect_type_objet' => 'Nom de camp incorr&egrave;cte @name@ t&agrave; obj&egrave;cte de tipe @type@',
'avis_colonne_inexistante' => 'La colomna @col@ n\'existeish pas',
'avis_echec_syndication_01' => 'La sindicacion que s\'i ei mauescaduda: lo backend indicat qu\'ei indeschifrable o non perpausa pas nat article.',
'avis_echec_syndication_02' => 'La sindicacion que s\'i ei mauescaduda: impossible d\'accedir au backend d\'aqueth sit.',
'avis_erreur' => 'Error: vejatz &ccedil;a devath',
'avis_erreur_connexion' => 'Error de connexion',
'avis_erreur_cookie' => 'probl&egrave;ma de cookie',
'avis_erreur_fonction_contexte' => 'Error de programacion. Non cau pas aperar aquera foncion dens aqueth cont&egrave;xt.',
'avis_erreur_mysql' => 'Error SQL ',
'avis_erreur_sauvegarde' => 'Error dens la sauvagarda (@type@ @id_objet@)! ',
'avis_erreur_visiteur' => 'Probl&egrave;me d\'acc&egrave;s &agrave; l\'espace priv&eacute;', # NEW

// B
'barre_a_accent_grave' => 'Inserir ua A accent gr&egrave;u majuscula',
'barre_aide' => 'Utilizar las acorcidas tipograficas ent&agrave; enriquir la v&ograve;sta compaginacion',
'barre_e_accent_aigu' => 'Inserir ua E accent agut majuscula',
'barre_eo' => 'Inserir ua E dens l\'O',
'barre_eo_maj' => 'Inserir ua E dens l\'O majuscula', # MODIF
'barre_euro' => 'Inserir lo simb&egrave;u de l\'&egrave;uro: &#8364;',
'barre_gras' => 'Hicar en {{gras}}',
'barre_guillemets' => 'Enrodar dab &laquo; verguetas &raquo;',
'barre_guillemets_simples' => 'Enrodar dab „verguetas“',
'barre_intertitre' => 'Transformar en {{{intert&iacute;tol}}}',
'barre_italic' => 'Hicar en {italics}',
'barre_lien' => 'Transformar en [ligam ipert&egrave;xt->http://...]',
'barre_lien_input' => 'Volhatz indicar l\'adrei&ccedil;a deu v&ograve;ste ligam (que podetz indicar ua adrei&ccedil;a web devath la forma http://www.lomensit.com o simplament indicar lo num&egrave;ro d\'un article d\'aqueth sit).',
'barre_note' => 'Transformar en [[N&ograve;ta de p&egrave;]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
'barre_quote' => '<quote>Citar un messatge</quote>',
'bouton_ajouter_document' => 'AJUSTAR UN DOCUMENT', # MODIF
'bouton_ajouter_image' => 'AJUSTAR UN IMATGE', # MODIF
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
'bouton_changer' => 'Cambiar',
'bouton_chercher' => 'Cercar',
'bouton_choisir' => 'Causir',
'bouton_download' => 'T&eacute;l&eacute;charger', # NEW
'bouton_enregistrer' => 'Registrar',
'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la messatjaria int&egrave;rna',
'bouton_radio_envoi_annonces' => 'Mandar los anoncis editoriaus',
'bouton_radio_non_envoi_annonces' => 'Non mandar pas nat anonci',
'bouton_radio_non_envoi_liste_nouveautes' => 'Non mandar pas la t&egrave;ra de las nautats',
'bouton_recharger_page' => 'tornar cargar aquera pagina',
'bouton_telecharger' => 'Telecargar',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'tant&ograve;st',
'cal_jour_entier' => 'dia enti&egrave;r',
'cal_matin' => 'matin',
'cal_par_jour' => 'calend&egrave;r per dia',
'cal_par_mois' => 'calend&egrave;r per mes',
'cal_par_semaine' => 'calend&egrave;r per setmana',
'choix_couleur_interface' => 'couleur ', # NEW
'choix_interface' => 'choix  de l\'interface', # NEW
'colonne' => 'Colonne', # NEW
'confirm_changer_statut' => 'Atencion, qu\'avetz demandat de cambiar l\'estatut d\'aqueth element. E desiratz de contunhar? ',
'correcte' => 'correcte', # NEW

// D
'date_aujourdhui' => 'uei',
'date_avant_jc' => 'abans lo Crist',
'date_dans' => 'd\'aqu&iacute; @delai@',
'date_de_mois_1' => '@j@ de gen&egrave;r',
'date_de_mois_10' => '@j@ d\'oct&ograve;bre',
'date_de_mois_11' => '@j@ de noveme',
'date_de_mois_12' => '@j@ de deceme',
'date_de_mois_2' => '@j@ de heur&egrave;r',
'date_de_mois_3' => '@j@ de mar&ccedil;',
'date_de_mois_4' => '@j@ d\'abriu',
'date_de_mois_5' => '@j@ de mai',
'date_de_mois_6' => '@j@ de junh',
'date_de_mois_7' => '@j@ de julhet',
'date_de_mois_8' => '@j@ d\'agost',
'date_de_mois_9' => '@j@ de seteme',
'date_demain' => 'deman',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ a @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@ de @annee@',
'date_fmt_mois_annee' => '@nommois@ de @annee@',
'date_fmt_nomjour_date' => 'lo @nomjour@ @date@',
'date_heures' => '&ograve;ras',
'date_hier' => 'i&egrave;r',
'date_il_y_a' => '@delai@ a',
'date_jnum1' => '1r',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'dimenge',
'date_jour_1_abbr' => 'dim.', # NEW
'date_jour_1_initiale' => 'd.', # NEW
'date_jour_2' => 'diluns',
'date_jour_2_abbr' => 'lun.', # NEW
'date_jour_2_initiale' => 'l.', # NEW
'date_jour_3' => 'dimars',
'date_jour_3_abbr' => 'mar.', # NEW
'date_jour_3_initiale' => 'm.', # NEW
'date_jour_4' => 'dim&egrave;rcs',
'date_jour_4_abbr' => 'mer.', # NEW
'date_jour_4_initiale' => 'm.', # NEW
'date_jour_5' => 'dijaus',
'date_jour_5_abbr' => 'jeu.', # NEW
'date_jour_5_initiale' => 'j.', # NEW
'date_jour_6' => 'div&eacute;s',
'date_jour_6_abbr' => 'ven.', # NEW
'date_jour_6_initiale' => 'v.', # NEW
'date_jour_7' => 'dissabte',
'date_jour_7_abbr' => 'sam.', # NEW
'date_jour_7_initiale' => 's.', # NEW
'date_jours' => 'dias',
'date_minutes' => 'minutas',
'date_mois' => 'mes',
'date_mois_1' => 'gen&egrave;r',
'date_mois_10' => 'oct&ograve;bre',
'date_mois_11' => 'noveme',
'date_mois_12' => 'deceme',
'date_mois_2' => 'heur&egrave;r',
'date_mois_3' => 'mar&ccedil;',
'date_mois_4' => 'abriu',
'date_mois_5' => 'mai',
'date_mois_6' => 'junh',
'date_mois_7' => 'julhet',
'date_mois_8' => 'agost',
'date_mois_9' => 'seteme',
'date_saison_1' => 'iv&egrave;rn',
'date_saison_2' => 'prima',
'date_saison_3' => 'estiu',
'date_saison_4' => 'ag&ograve;r',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'setmana(s)',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => 'ent&agrave; comen&ccedil;ar vertad&egrave;rament l\'installacion',
'dirs_preliminaire' => 'Preliminar: <b>Reglar los drets d\'acc&egrave;s</b>',
'dirs_probleme_droits' => 'Probl&egrave;ma de drets d\'acc&egrave;s', # MODIF
'dirs_repertoires_absents' => '<b>Non s\'ei pas trobat los repert&ograve;ris seguents: <ul>@bad_dirs@.</ul> </b>
  <p>Que\'s p&ograve;t que venga d\'un probl&egrave;ma de majusculas o minusculas mau hicadas.
  Verificatz que las minusculas e majusculas d\'aqueths repert&ograve;ris e corresp&oacute;nian plan dab &ccedil;&ograve; d\'afichat
  &ccedil;a sus; se n\'ei pas lo cas, tornatz nommar los repert&ograve;ris dab lo v&ograve;ste logiciau FTP en corregir l\'error.
  <p>Un c&ograve;p qu\'auratz h&egrave;it aqu&ograve;, que poiratz ', # MODIF
'dirs_repertoires_suivants' => '<b>Los repert&ograve;ris seguents non son pas accessibles en escritura: <ul>@bad_dirs@.</ul> </b>
  <p>Ent&agrave; adobar aqu&ograve;, utilizatz lo v&ograve;ste client FTP ent&agrave; reglar los drets d\'acc&egrave;s de cadun
  d\'aqueths repert&ograve;ris. La guida d\'installacion qu\'explica en detalh quin cau procedir.
  <p>Tanl&egrave;u qu\'auratz h&egrave;ita aquera manipulacion, que poiratz ', # MODIF
'double_occurrence' => 'Double occurrence', # MODIF

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Dimensions:',
'entree_titre_document' => 'T&iacute;tol deu document:',
'entree_titre_image' => 'T&iacute;tol de l\'imatge:',
'envoi_via_le_site' => 'Mandad&iacute;s dab lo biaish deu sit web',
'erreur' => 'Erreur', # NEW
'erreur_balise_non_fermee' => 'derni&egrave;re balise non referm&eacute;e :', # NEW
'erreur_texte' => 'erreur(s)', # NEW
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'Non s\'ei pas pogut trobar lo fichi&egrave;r @fichier@.',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Qu\'&egrave;tz ja inscriut(a).',
'form_email_non_valide' => 'La v&ograve;sta adrei&ccedil;a e-mail n\'ei pas valida.',
'form_forum_access_refuse' => 'Non podetz plus accedir a aqueth sit.',
'form_forum_bonjour' => 'Adishatz @nom@,,',
'form_forum_email_deja_enregistre' => 'Aquera adrei&ccedil;a e-mail ja qu\'ei registrada, doncas que podetz utilizar lo v&ograve;ste mot de santa Clara costum&egrave;r.',
'form_forum_identifiant_mail' => 'Que vs\'av&egrave;m mandat lo v&ograve;ste identificant nav&egrave;th per e-mail.',
'form_forum_identifiants' => 'Identificants personaus',
'form_forum_indiquer_nom_email' => 'Indicatz aqu&iacute; lo v&ograve;ste nom e la v&ograve;sta adrei&ccedil;a e-mail. Lo v&ograve;ste identificant personau qu\'arribar&agrave; l&egrave;u-l&egrave;u, per e-mail.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(aqu&ograve; qu\'ei un messatge automatic)',
'form_forum_pass' => 'mot de santa Clara:',
'form_forum_probleme_mail' => 'Probl&egrave;ma d\'e-mail: ne\'s p&ograve;t pas mandar l\'identificant.',
'form_forum_voici1' => 'Ti&egrave;tz los v&ograve;stes identificants ent&agrave; poder participar aus forums
deu sit "@nom_site_spip@" (@adresse_site@):', # MODIF
'form_forum_voici2' => 'Ti&egrave;tz los v&ograve;stes identificants ent&agrave; perpausar articles 
 suu sit "@nom_site_spip@" (@adresse_login@):', # MODIF
'form_indiquer_email' => 'Volhatz indicar la v&ograve;sta adrei&ccedil;a e-mail.',
'form_indiquer_nom' => 'Volhatz indicar lo v&ograve;ste nom.',
'form_indiquer_nom_site' => 'Volhatz indicar lo nom deu v&ograve;ste sit.',
'form_pet_adresse_site' => 'Adrei&ccedil;a deu v&ograve;ste sit',
'form_pet_aucune_signature' => 'Nada signatura non correspond pas a aqueth c&ograve;de...',
'form_pet_confirmation' => 'Volhatz confirmar la v&ograve;sta signatura:',
'form_pet_deja_enregistre' => 'Ja aqueth sit qu\'ei registrat',
'form_pet_deja_signe' => 'Qu\'avetz ja signat aqueth t&egrave;xt.',
'form_pet_envoi_mail_confirmation' => 'Ara que receberatz un e-mail de confirmacion. T&agrave; validar la v&ograve;sta signatura, que cau vesitar l\'adrei&ccedil;a web men&ccedil;onada per aqueste corri&egrave;r.', # MODIF
'form_pet_mail_confirmation' => 'Adishatz,

qu\'avetz demandat de signar la peticion:
@titre@.

Qu\'avetz hornidas las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
T&agrave; validar la v&ograve;sta signatura, que suf&iacute;s de\'vs connectar a 
 l\'adrei&ccedil;a &ccedil;a devath (senon que\'s regetar&agrave;
la v&ograve;sta demanda): 
    @url@


Merc&eacute;s ent&agrave; la v&ograve;sta participacion
', # MODIF
'form_pet_message_commentaire' => 'Un messatge, ua remarca?',
'form_pet_nom_site2' => 'Nom deu v&ograve;ste sit web',
'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
'form_pet_probleme_technique' => 'Probl&egrave;ma tecnic, las signaturas que son tempor&agrave;riament arrestadas.',
'form_pet_signature_pasprise' => 'La v&ograve;sta signatura n\'ei pas presa en compte.',
'form_pet_signature_validee' => 'La v&ograve;sta signatura qu\'ei validada. Merc&eacute;s!',
'form_pet_site_deja_enregistre' => 'Ja aqueth sit qu\'ei registrat',
'form_pet_url_invalide' => 'L\'URL qui avetz indicada n\'ei pas valida.',
'form_pet_votre_email' => 'La v&ograve;sta adrei&ccedil;a e-mail',
'form_pet_votre_nom' => 'Lo v&ograve;ste nom o pseudonim',
'form_pet_votre_site' => 'Se tienetz un sit, qu\'ac podetz marcar &ccedil;a devath',
'form_prop_confirmer_envoi' => 'Confirmar lo mandad&iacute;s',
'form_prop_description' => 'Descripcion/comentari',
'form_prop_enregistre' => 'La v&ograve;sta proposicion qu\'ei plan registrada, qu\'apareisher&agrave; en linha tanl&egrave;u que los responsables deu sit e l\'aur&agrave;n validada .',
'form_prop_envoyer' => 'Mandar un messatge',
'form_prop_indiquer_email' => 'Volhatz indicar ua adrei&ccedil;a e-mail valida',
'form_prop_indiquer_nom_site' => 'Volhatz indicar lo nom deu sit.',
'form_prop_indiquer_sujet' => 'Volhatz indicar un subj&egrave;cte',
'form_prop_message_envoye' => 'Messatge mandat',
'form_prop_nom_site' => 'Nom deu sit',
'form_prop_non_enregistre' => 'La v&ograve;sta proposicion n\'ei pas estada registrada.',
'form_prop_sujet' => 'Subj&egrave;cte',
'form_prop_url_site' => 'Adrei&ccedil;a (URL) deu sit',
'forum_acces_refuse' => 'Non podetz plus accedir a aqueths forums.',
'forum_attention_dix_caracteres' => '<b>Atencion!</b> lo v&ograve;ste messatge que deu ti&eacute;ner aumensh d&egrave;tz caract&egrave;rs.',
'forum_attention_trois_caracteres' => '<b>Atencion!</b> lo v&ograve;ste t&iacute;tol que deu ti&eacute;ner aumensh de tres caract&egrave;rs.',
'forum_attention_trop_caracteres' => '<b>Attention&nbsp;!</b> votre message est trop long (@compte@ caract&egrave;res)&nbsp;: pour pouvoir &ecirc;tre enregistr&eacute;, il ne doit pas d&eacute;passer @max@ caract&egrave;res.', # NEW
'forum_avez_selectionne' => 'Qu\'avetz seleccionat:',
'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>ac&iacute;</a> t&agrave; contunhar.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Aqueste forum qu\'ei moderat a pri&ograve;ri: la v&ograve;sta contribucion que pareisher&agrave; sonque apr&egrave;s qu\'un administrator deu sit l\'aja validada.',
'forum_lien_hyper' => '<b>Ligam ipert&egrave;xt</b> (opcionau)',
'forum_message_definitif' => 'Messatge definitiu : mandar au sit',
'forum_message_trop_long' => 'Lo v&ograve;ste messatge qu\'ei tr&ograve;p long. La longor maximau qu\'ei de 20&nbsp;000 caract&egrave;rs.',
'forum_ne_repondez_pas' => 'Non responiatz pas a aqueth e-mail mes peu forum a l\'adrei&ccedil;a seguenta: ',
'forum_non_inscrit' => 'Sia n\'&egrave;tz pas inscriut(a), sia avetz h&egrave;it ua error d\'adrei&ccedil;a o de mot de santa Clara. ',
'forum_page_url' => '(se lo v&ograve;ste messatge e\'s refereish a un article publicat peu web, o a ua pagina qui baile mei informacions, que podetz marcar &ccedil;a devath lo t&iacute;tol de la pagina e la soa adrei&ccedil;a URL.)',
'forum_par_auteur' => 'per @auteur@',
'forum_poste_par' => 'Messatge poste@parauteur@ qui h&egrave; seguida au v&ograve;ste article.', # MODIF
'forum_probleme_database' => 'Probl&egrave;ma de basa de dadas, lo v&ograve;ste messatge non s\'ei pas registrat.',
'forum_qui_etes_vous' => '<b>Qui &egrave;tz?</b> (opcionau)',
'forum_texte' => 'T&egrave;xt deu v&ograve;ste messatge:',
'forum_titre' => 'T&iacute;tol:',
'forum_titre_erreur' => 'Error...',
'forum_url' => 'URL:',
'forum_valider' => 'Validar aquera causida',
'forum_voir_avant' => 'V&eacute;der lo messatge abans de\'u mandar',
'forum_votre_email' => 'La v&ograve;sta adrei&ccedil;a e-mail:',
'forum_votre_nom' => 'Lo v&ograve;ste nom (o pseudonim):',
'forum_vous_enregistrer' => 'Ent&agrave; participar a
  aqueth forum, en perm&egrave;ras que\'vs cau registrar. Merc&eacute;s
  de marcar &ccedil;a devath l\'identificant personau qui avetz recebut.
 Se n\'&egrave;tz pas registrat/ada, qu\'ei necessari',
'forum_vous_inscrire' => 'inscrive\'vs',

// I
'ical_texte_rss_articles' => 'Lo fichi&egrave;r "backend" deus articles d\'aqueste sit que\'s tr&ograve;ba a l\'adrei&ccedil;a:',
'ical_texte_rss_articles2' => 'Atanben que podetz obti&eacute;ner fichi&egrave;rs "backend" peus articles de cada rubrica deu sit:',
'ical_texte_rss_breves' => 'Qu\'existeishen mei d\'un fichi&egrave;r contienent las br&egrave;vas deu sit. En precisar un num&egrave;ro de rubrica, qu\'obtieneratz sonque las br&egrave;vas de la rubrica aquera.',
'icone_a_suivre' => 'De seguir',
'icone_admin_site' => 'Administracion deu sit',
'icone_agenda' => 'Agenda e messatjaria',
'icone_aide_ligne' => 'Ajuda',
'icone_articles' => 'Articles',
'icone_auteurs' => 'Autors',
'icone_breves' => 'Br&egrave;vas',
'icone_brouteur' => 'Navigacion rapida',
'icone_configuration_site' => 'Configuracion',
'icone_configurer_site' => 'Configurar lo v&ograve;ste sit',
'icone_creer_nouvel_auteur' => 'Crear un autor nau',
'icone_creer_rubrique' => 'Crear ua rubrica',
'icone_creer_sous_rubrique' => 'Crear ua sosrubrica',
'icone_deconnecter' => 'Desconnect&agrave;\'s',
'icone_discussions' => 'Discussions',
'icone_doc_rubrique' => 'Documents de las rubricas',
'icone_ecrire_article' => 'Escr&iacute;ver un article nau',
'icone_edition_site' => 'Edicion',
'icone_forum_administrateur' => 'Forum deus administrators',
'icone_forum_suivi' => 'Seguit deus forums',
'icone_gestion_langues' => 'Gestion de las lengas',
'icone_informations_personnelles' => 'Informacions personaus',
'icone_interface_complet' => 'Interf&agrave;cia completa',
'icone_interface_simple' => 'Interf&agrave;cia simplificada',
'icone_maintenance_site' => 'Mantienen&ccedil;a deu sit',
'icone_messagerie_personnelle' => 'Messatjaria personau',
'icone_mots_cles' => 'Mots clau',
'icone_nouvelle_breve' => 'Escr&iacute;ver ua br&egrave;va nava',
'icone_repartition_actuelle' => 'Afichar la reparticion actuau',
'icone_repartition_debut' => 'Afichar la reparticion dempuish la comen&ccedil;an&ccedil;a',
'icone_repartition_visites' => 'Reparticion de las vesitas',
'icone_rubriques' => 'Rubricas',
'icone_sauver_site' => 'Sauvagarda deu sit',
'icone_site_entier' => 'Tot lo sit ',
'icone_sites_references' => 'Sits referenciats',
'icone_statistiques' => 'Estadisticas deu sit',
'icone_statistiques_visites' => 'Estadisticas',
'icone_suivi_activite' => 'Seguir l\'activitat editoriau',
'icone_suivi_actualite' => 'Evolucion deu sit',
'icone_suivi_forums' => 'Seguir/gerir los forums',
'icone_suivi_pettions' => 'Seguir/gerir las peticions',
'icone_suivi_revisions' => 'Modificacions deus articles',
'icone_supprimer_document' => 'Suprimir aqueth document',
'icone_supprimer_image' => 'Suprimir aqueth imatge',
'icone_supprimer_message' => 'Suprimir aqueth messatge',
'icone_tous_articles' => 'Tots los v&ograve;stes articles ',
'icone_tous_auteur' => 'Tots los autors ',
'icone_valider_message' => 'Validar aqueth messatge',
'icone_visiter_site' => 'Vesitar',
'icone_voir_en_ligne' => 'V&eacute;der en linha',
'image_tourner_180' => 'Rotacion 180&deg;',
'image_tourner_droite' => 'Rotacion 90&deg; cap a dreta',
'image_tourner_gauche' => 'Rotacion 90&deg; cap a esqu&egrave;rra',
'img_indisponible' => 'imatge indisponible',
'impossible' => 'impossible', # NEW
'info_a_suivre' => 'DE SEGUIR&gt;&gt;',
'info_a_valider' => '[de validar]',
'info_acces_interdit' => 'Acc&egrave;s pro&iuml;bit',
'info_acces_refuse' => 'Acc&egrave;s arrefusat',
'info_action' => 'Accion: @action@',
'info_administrer_rubriques' => 'Que podetz administrar aquera rubrica e las soas sosrubricas',
'info_adresse_non_indiquee' => 'N\'av&egrave;tz pas indicat l\'adrei&ccedil;a de testar!',
'info_aide' => 'AJUDA:',
'info_ajouter_mot' => 'Ajustar aqueth mot',
'info_annonce' => 'ANONCI',
'info_annonces_generales' => 'Anoncis generaus:',
'info_article_propose' => 'Article perpausat',
'info_article_publie' => 'Article publicat',
'info_article_redaction' => 'Article en cors de redaccion',
'info_article_refuse' => 'Article arrefusat',
'info_article_supprime' => 'Article suprimit',
'info_articles' => 'Articles',
'info_articles_a_valider' => 'Los articles de validar',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Articles perpausats',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autor(s)',
'info_authentification_ftp' => 'autentificacion (per FTP).',
'info_bloquer_lien' => 'Blocar aqueth ligam',
'info_breves_02' => 'Br&egrave;vas',
'info_breves_2' => 'br&egrave;vas',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Br&egrave;vas de validar',
'info_connexion_refusee' => 'Connexion arrefusada',
'info_contact_developpeur' => 'Volhatz contactar un desvolopaire.',
'info_contenance' => 'Aqueth sit que contien:',
'info_contribution' => 'Contribucions de forum',
'info_copyright' => '@spip@ qu\'ei un logiciau liure distribuit @lien_gpl@.',
'info_copyright_doc' => 'Per mei informacions, v&eacute;der lo sit <a href="@spipnet@">http://www.spip.net/oc</a>.', # MODIF
'info_copyright_gpl' => 'devath lic&eacute;ncia GPL',
'info_cours_edition' => 'Los v&ograve;stes articles en cors de redaccion',
'info_creer_repertoire' => 'Volhatz crear un fichi&egrave;r o un repert&ograve;ri nomentat',
'info_creer_repertoire_2' => 'laguens lo sosrepert&ograve;ri   <b>@repertoire@</b>, puish:', # MODIF
'info_creer_vignette' => 'creacion automatica de la vinheta',
'info_deplier' => 'Desplegar',
'info_descriptif_nombre' => 'descriptiu(s):',
'info_description' => 'Descripcion:',
'info_description_2' => 'Descripcion:',
'info_dimension' => 'Dimensions:',
'info_document' => 'Document ',
'info_document_indisponible' => 'Ce document n\'est pas disponible', # NEW
'info_documents' => 'Documents',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP que permet d\'escambiar messatges e de constituir forums privats de discussion entre los participants deu sit. Que podetz activar o desactivar aquera foncionalitat.',
'info_ecire_message_prive' => 'Escr&iacute;ver un messatge privat',
'info_email_invalide' => 'Adrei&ccedil;a e-mail invalida',
'info_en_cours_validation' => 'Los v&ograve;stes articles en cors de redaccion',
'info_en_ligne' => 'Ara en linha:',
'info_envoyer_message_prive' => 'Mandar un messatge privat a aqueth autor',
'info_erreur_requete' => 'Error dens la requ&egrave;sta',
'info_erreur_squelette2' => 'Nada esqueleta <b>@fichier@</b> n\'ei pas disponibla...',
'info_erreur_systeme' => 'Error sist&egrave;ma (errno @errsys@)',
'info_erreur_systeme2' => 'Lo disc dur qu\'ei dilh&egrave;u plen, o la basa de dadas gastada. <br />
 <font color=\'red\'>Ensajatz de <a href=\'@script@\'>reparar la basa</a>,
 o contactatz lo v&ograve;ste aubergader.</font>', # MODIF
'info_fini' => 'Qu\'ei acabat!',
'info_format_image' => 'Formats d\'imatges qui\'s p&ograve;den utilizar t&agrave; crear vinhetas: @gd_formats@.',
'info_format_non_defini' => 'format non definit',
'info_grand_ecran' => 'Ecran gran ',
'info_image_aide' => 'AJUDA',
'info_image_process_titre' => 'Met&ograve;de de fabricacion de las vinhetas',
'info_impossible_lire_page' => '<b>Error!</b> Impossible de legir la pagina <tt><html>@test_proxy@</html></tt> a trav&egrave;rs deu proxy <tt>', # MODIF
'info_inclusion_directe' => 'Inclusion dir&egrave;cta:',
'info_inclusion_vignette' => 'Inclusion de la vinheta:',
'info_installation_systeme_publication' => 'Installacion deu sist&egrave;ma de publicacion...',
'info_installer_documents' => 'Que podetz installar automaticament tots los documents contenguts dens lo repert&ograve;ri @upload@.', # MODIF
'info_installer_ftp' => 'Com administrator, que podetz installar (per FTP) fichi&egrave;rs dens lo dorsi&egrave;r @upload@, puish seleccion&agrave;\'us dir&egrave;ctament ac&iacute;.', # MODIF
'info_installer_images' => 'Que podetz installar imatges aus formats JPEG, GIF e PNG.',
'info_installer_images_dossier' => 'Installar imatges dens lo dorsi&egrave;r @upload@ ent&agrave;\'us poder seleccionar ac&iacute;.', # MODIF
'info_installer_tous_documents' => 'Installar tots los documents ',
'info_interface_complete' => 'Interf&agrave;cia completa',
'info_interface_simple' => 'Interf&agrave;cia simplificada',
'info_joindre_document_article' => 'Que podetz j&oacute;nher a aqueth article documents de la traca de',
'info_joindre_document_rubrique' => 'Que podetz ajustar a aquera rubrica documents de la traca de',
'info_joindre_documents_article' => 'Que podetz j&oacute;nher a aqueth article documents de la traca de:',
'info_l_article' => 'l\'article',
'info_la_breve' => 'la br&egrave;va',
'info_la_rubrique' => 'la rubrica',
'info_langue_principale' => 'Lenga majorau deu sit',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pix&egrave;ls',
'info_les_auteurs_1' => 'per @les_auteurs@ ',
'info_logo_format_interdit' => 'Los l&ograve;gos de formats @formats@ que son sols autorizats.',
'info_logo_max_poids' => 'Los l&ograve;gos qu\'an de har mensh de @maxi@ (aqueste fichi&egrave;r que h&egrave; @actuel@).',
'info_logo_max_taille' => 'Los l&ograve;gos qu\'an de har mensh de @maxi@ (aqueste fichi&egrave;r que h&egrave; @actuel@).',
'info_mail_fournisseur' => 'vos@hornider.com',
'info_message_2' => 'MESSATGE',
'info_message_supprime' => 'MESSATGE SUPRIMIT',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Data de hicada en linha:',
'info_modification_parametres_securite' => 'modificacions deus param&egrave;tres de seguretat',
'info_mois_courant' => 'Dens lo corrent deu mes:',
'info_mot_cle_ajoute' => 'Que s\'ei ajustat lo mot clau seguent a ',
'info_multi_herit' => 'Lenga predefinida',
'info_multi_langues_soulignees' => 'Las <u>lengas solinhadas</u> que benef&iacute;cian d\'ua arrevirada de tots los t&egrave;xts de l\'interf&agrave;cia. Se seleccionatz aqueras lengas, h&egrave;ra d\'elements deu sit public (datas, formularis) que s\'arrevirar&agrave;n automaticament. Ent&agrave; las lengas non solinhadas, aqueths elements qu\'apareisher&agrave;n dens la lenga principau deu sit.',
'info_multilinguisme' => 'Multiling&uuml;isme',
'info_nom_non_utilisateurs_connectes' => 'Lo v&ograve;ste nom n\'apareish pas dens la t&egrave;ra deus utilizaires connectats.',
'info_nom_utilisateurs_connectes' => 'Lo v&ograve;ste nom qu\'apareish dens la t&egrave;ra deus utilizaires connectats.',
'info_nombre_en_ligne' => 'Ara en linha:',
'info_non_resultat' => 'Nat resultat ent&agrave; "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'N\'utilizatz pas la messatjaria int&egrave;rna d\'aqueth sit.',
'info_nouveau_message' => 'QU\'AVETZ UN MESSATGE NAU',
'info_nouveaux_messages' => 'QU\'AVETZ @total_messages@ MESSATGES NAUS',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Sit sindicat en pana',
'info_pense_bete' => 'MEMENTO',
'info_petit_ecran' => 'Ecran petit ',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'pix&egrave;ls',
'info_plusieurs_mots_trouves' => 'Mei d\'un mot clau trobat per "@cherche_mot@":',
'info_popularite_5' => 'popularitat:',
'info_portfolio' => 'P&ograve;rtf&ograve;lio',
'info_portfolio_automatique' => 'P&ograve;rtf&ograve;lio automatic:',
'info_premier_resultat' => '[@debut_limit@ perm&egrave;rs resultats de @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ perm&egrave;rs resultats de @total@]',
'info_probleme_grave' => 'probl&egrave;ma de',
'info_propose_1' => '[@nom_site_spip@] Que perpausa: @titre@',
'info_propose_2' => 'Article perpausat
---------------',
'info_propose_3' => 'L\'article "@titre@" qu\'ei perpausat a la publicacion.',
'info_propose_4' => 'Que\'vs convidam a vi&eacute;ner consult&agrave;\'u e a bailar la v&ograve;sta id&egrave;a',
'info_propose_5' => 'dens lo forum qui l\'ei estacat. Qu\'ei disponible a l\'adrei&ccedil;a:',
'info_publie_01' => 'L\'article "@titre@" qu\'ei estat validat per @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] QUE PUBLICA: @titre@',
'info_publie_2' => 'Article publicat--------------',
'info_rechercher' => 'Cercar',
'info_rechercher_02' => 'Cercar:',
'info_remplacer_vignette' => 'Rempla&ccedil;ar la vinheta predefinida per un l&ograve;go personalizat:',
'info_retablir_lien' => 'Restablir aqueth ligam',
'info_retirer_mot' => 'Quitar aqueth mot',
'info_retirer_mots' => 'Quitar tots los mots ',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'shens t&iacute;tol',
'info_selectionner_fichier' => 'Que podetz seleccionar un fichi&egrave;r deu dorsi&egrave;r @upload@', # MODIF
'info_selectionner_fichier_2' => 'Seleccionar un fichi&egrave;r:',
'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
'info_site_attente' => 'Sit web en esp&egrave;ra de validacion',
'info_site_reference' => 'Sit referenciat en linha',
'info_site_refuse' => 'Sit web arrefusat',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Referenciar un sit',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'suprimir la vinheta',
'info_symbole_bleu' => 'Lo simb&egrave;u <b>blau</b> que marca un <b>memento</b>: qu\'ei a d&iacute;ser un messatge tau v&ograve;ste usatge personau.', # MODIF
'info_symbole_jaune' => 'Lo simb&egrave;u <b>jaune</b> que marca un <b>anonci t&agrave; tots los redactors </b>: los administrators que\'u p&ograve;den modificar, cada redactor que\'u p&ograve;t v&eacute;der.', # MODIF
'info_symbole_vert' => 'Lo simb&egrave;u <b>verd</b> que marca los <b>messatges escambiats dab autes utilizaires</b> deu sit.', # MODIF
'info_syndication' => 'sindicacion:',
'info_syndication_articles' => 'article(s)',
'info_telecharger' => 'Telecargar a partir deu v&ograve;ste ordenader:',
'info_telecharger_nouveau_logo' => 'Telecargar un l&ograve;go nau:',
'info_telecharger_ordinateur' => 'Telecargar a partir deu v&ograve;ste ordenader:',
'info_tous_resultats_enregistres' => '[tots los resultats que son registrats]',
'info_tout_afficher' => 'Afichar tot',
'info_travaux_texte' => 'Aqueth sit n\'ei pas enq&uuml;&egrave;ra configurat. Tornatz mei tard...',
'info_travaux_titre' => 'Sit en &ograve;bras',
'info_trop_resultat' => 'Tr&ograve;p de resultats ent&agrave; "@cherche_mot@"; volhatz afinar la c&egrave;rca.',
'info_utilisation_messagerie_interne' => 'Qu\'utilizatz la messatjaria int&egrave;rna d\'aqueth sit.',
'info_valider_lien' => 'validar aqueth ligam',
'info_verifier_image' => ', volhatz verificar que los imatges e\'s sian plan transferits.',
'info_vignette_defaut' => 'Vinheta predefinidas ',
'info_vignette_personnalisee' => 'Vinheta personalizada',
'info_visite' => 'vesita:',
'info_visites' => 'vesitas:',
'info_vos_rendez_vous' => 'Los v&ograve;stes rendetz-vos qui vienen',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Los v&ograve;stes mementos', # MODIF
'item_breve_proposee' => 'Br&egrave;va perpausada',

// L
'lien_afficher_icones_seuls' => 'Afichar sonque las ic&ograve;nas',
'lien_afficher_texte_icones' => 'Afichar las ic&ograve;nas e lo t&egrave;xt',
'lien_afficher_texte_seul' => 'Afichar sonque lo t&egrave;xt',
'lien_liberer' => 'liberar',
'lien_liberer_tous' => 'liberar aqueths articles',
'lien_nouvea_pense_bete' => 'MEMENTO NAU ',
'lien_nouveau_message' => 'MESSATGE NAU',
'lien_nouvelle_annonce' => 'ANONCI NAV&Egrave;TH',
'lien_petitions' => 'PETICION',
'lien_popularite' => 'popularitat: @popularite@%',
'lien_racine_site' => 'ARRADIT DEU SIT',
'lien_reessayer' => 'tornar ensajar',
'lien_repondre_message' => 'Resp&oacute;ner a aqueth messatge',
'lien_supprimer' => 'suprimir',
'lien_tout_afficher' => 'Afichar tot',
'lien_visite_site' => 'vesitar aqueth sit',
'lien_visites' => '@visites@&nbsp;vesitas',
'lien_voir_auteur' => 'V&eacute;der aqueth autor',
'ligne' => 'Ligne', # NEW
'login' => 'Connexion', # NEW
'login_acces_prive' => 'acc&egrave;s a l\'espaci privat',
'login_autre_identifiant' => 'connect&agrave;\'s dab un aute identificant',
'login_cookie_accepte' => 'Volhatz configurar lo v&ograve;ste navigader t&agrave; que\'us acc&egrave;pte (aumensh t&agrave; aqueth sit).',
'login_cookie_oblige' => 'Ent&agrave; vs\'identificar d\'ua man&egrave;ra segura sus aqueste sit, que\'vs cau acceptar los cookies.',
'login_deconnexion_ok' => 'Qu\'&egrave;tz desconnectat/ada.',
'login_erreur_pass' => 'Error de mot de santa Clara.',
'login_espace_prive' => 'espaci privat',
'login_identifiant_inconnu' => 'L\'identificant &laquo;@login@&raquo; qu\'ei inconegut.',
'login_login' => 'Login:',
'login_login2' => 'Login (identificant de connexion au sit):',
'login_login_pass_incorrect' => '(Login o mot de santa Clara incorr&egrave;cte.)',
'login_motpasseoublie' => 'mot&nbsp;de&nbsp;santa&nbsp;Clara&nbsp;oblidat?',
'login_non_securise' => 'Atencion, aqueth formulari n\'ei pas securizat.
    Se non voletz pas que lo v&ograve;ste mot de santa Clara sia
   interceptat sus l\'arret, volhatz activar Javascript 
   dens lo v&ograve;ste navigader e',
'login_nouvelle_tentative' => 'nav&egrave;th ensai',
'login_par_ici' => 'Qu\'&egrave;tz registrat/ada... per aqu&iacute;...',
'login_pass2' => 'Mot de santa Clara:',
'login_preferez_refuser' => '<b>Se vs\'agrada mei d\'arrefusar los cookies</b>, un aute met&ograve;de de connexion (mensh securizat) qu\'ei a la v&ograve;sta disposicion:',
'login_recharger' => 'tornar cargar aquera pagina',
'login_rester_identifie' => 'Demorar identificat quauques dias',
'login_retour_public' => 'Tornar au sit public',
'login_retour_site' => 'Tornar au sit public',
'login_retoursitepublic' => 'tornar&nbsp;au&nbsp;sit&nbsp;public',
'login_sans_cookiie' => 'Identificacion shens cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'inscrive\'s',
'login_test_navigateur' => 'Ensai navigader/tornar&nbsp;connectar',
'login_verifiez_navigateur' => '(totun verificatz que lo v&ograve;ste navigader n\'aja pas servat lo v&ograve;ste mot de santa Clara en mem&ograve;ria...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'masquer les traductions', # NEW
'module_fichiers_langues' => 'Fichi&egrave;rs de lenga',

// N
'navigateur_pas_redirige' => 'Se lo v&ograve;ste navigader n\'ei pas redirigit, clicatz ac&iacute; t&agrave; contunhar.',
'numero' => 'Num&eacute;ro', # NEW

// O
'occurence' => 'Occurrence', # NEW
'onglet_affacer_base' => 'Esfa&ccedil;ar la basa',
'onglet_auteur' => 'L\'autor',
'onglet_contenu_site' => 'Contengut deu sit',
'onglet_evolution_visite_mod' => 'Evolucion',
'onglet_fonctions_avances' => 'Foncions avan&ccedil;adas',
'onglet_informations_personnelles' => 'Informacions personaus',
'onglet_interactivite' => 'Interactivitat',
'onglet_messagerie' => 'Messatjaria',
'onglet_messages_internes' => 'Messatges int&egrave;rnes',
'onglet_messages_publics' => 'Messatges publics',
'onglet_messages_vide' => 'Messatges shens t&egrave;xt',
'onglet_origine_visites' => 'Origina de las vesitas',
'onglet_repartition_debut' => 'dempuish la comen&ccedil;an&ccedil;a',
'onglet_repartition_lang' => 'Reparticion per lengas',
'onglet_repartition_rubrique' => 'Reparticion per rubricas',
'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
'onglet_vider_cache' => 'Vueidar l\'esconeder',

// P
'pass_choix_pass' => 'Volhatz causir lo v&ograve;ste mot de santa Clara nav&egrave;th:',
'pass_erreur' => 'Error',
'pass_erreur_acces_refuse' => '<b>Error:</b> non podetz plus accedir a aqueth sit.',
'pass_erreur_code_inconnu' => '<b>Error:</b> aqueth c&ograve;de non correspond pas a nat vesitaire qui posca accedir a aqueth sit.',
'pass_erreur_non_enregistre' => '<b>Error:</b> l\'adrei&ccedil;a <tt>@email_oubli@</tt> n\'ei pas registrada sus aqueth sit.',
'pass_erreur_non_valide' => '<b>Error:</b> aqueth e-mail <tt>@email_oubli@</tt> n\'ei pas valid!',
'pass_erreur_probleme_technique' => '<b>Error:</b> pr\'amor d\'un probl&egrave;ma tecnic, l\'e-mail ne\'s p&ograve;t pas mandar. ',
'pass_espace_prive_bla' => 'L\'espaci privat d\'aqueste sit qu\'ei dob&egrave;rt aus
  vesitaires qui\'s son inscriuts. Un c&ograve;p registrat/ada,
  que poiratz consultar los articles en cors de redaccion,
  perpausar articles nav&egrave;ths e participar a tots los forums.',
'pass_forum_bla' => 'Qu\'avetz demandat d\'intervi&eacute;ner dens un forum
  reservat aus vesitaires registrats.',
'pass_indiquez_cidessous' => 'Marcatz &ccedil;a devath l\'adrei&ccedil;a e-mail on
 vos registr&egrave;tz lo c&ograve;p passat. 
   Que receberatz un e-mail qui\'vs bailar&agrave; la man&egrave;ra de 
    tornar trobar lo v&ograve;ste acc&egrave;s.',
'pass_mail_passcookie' => '(aqu&ograve; qu\'ei un messatge automatic)
T&agrave; tornar trobar lo v&ograve;ste acc&egrave;s au sit
@nom_site_spip@ (@adresse_site@)

Volhatz anar a l\'adrei&ccedil;a seguenta:

    @sendcookie@

Alavetz que poiratz entrar un mot de santa Clara nav&egrave;th
e tornar connect&agrave;\'vs au sit.

', # MODIF
'pass_mot_oublie' => 'Mot de santa Clara desmembrat',
'pass_nouveau_enregistre' => 'Lo v&ograve;ste mot de santa Clara nav&egrave;th qu\'ei estat registrat.',
'pass_nouveau_pass' => 'Mot de santa Clara nav&egrave;th',
'pass_ok' => 'D\'ac&ograve;rd',
'pass_oubli_mot' => 'Mot de santa Clara desmembrat',
'pass_quitter_fenetre' => 'Quitar aquesta frin&egrave;sta ',
'pass_rappel_login' => 'Remembran&ccedil;a: lo v&ograve;ste identificant (login) qu\'ei &laquo;@login@&raquo;.',
'pass_recevoir_mail' => 'Que receberatz un e-mail qui vs\'explicar&agrave; quin tornar trobar lo v&ograve;ste acc&egrave;s au sit.',
'pass_retour_public' => 'Tornar au sit public',
'pass_rien_a_faire_ici' => 'Pas arren a har ac&iacute;.',
'pass_vousinscrire' => 'Inscrive\'s sus aqueste sit',
'precedent' => 'precedent',
'previsualisation' => 'Previsualizacion',
'previsualiser' => 'Previsualizar',

// R
'retour' => 'Retour', # NEW

// S
'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :', # NEW
'squelette' => 'squelette', # NEW
'squelette_inclus_ligne' => 'squelette inclus, ligne', # NEW
'squelette_ligne' => 'squelette, ligne', # NEW
'stats_visites_et_popularite' => '@visites@ vesitas; popularitat: @popularite@',
'suivant' => 'seguent',

// T
'taille_ko' => '@taille@&nbsp;Ko',
'taille_mo' => '@taille@&nbsp;Mo',
'taille_octets' => '@taille@&nbsp;octets',
'texte_actualite_site_1' => 'Quan vos seretz familharizat/ada dab l\'interf&agrave;cia, que poiratz clicar sus &laquo;',
'texte_actualite_site_2' => 'Interf&agrave;cia completa',
'texte_actualite_site_3' => '" t&agrave; aubrir mei possibilitats.',
'texte_creation_automatique_vignette' => 'La creacion automatica de vinhetas de previsualizacion qu\'ei activada sus aqueth sit. S\'installatz a partir d\'aqueth formulari d\'imatges au(s) format(s) @gd_formats@, que s\'acompanhar&agrave;n d\'ua vinheta d\'ua talha maximau de @taille_preview@ pix&egrave;ls.',
'texte_documents_associes' => 'Los documents seguents que s\'ass&ograve;cian a l\'article,
 mes non s\'insereishen pas
 dir&egrave;ctament. Segon la compaginacion deu sit public,
 que poir&agrave;n apar&eacute;isher devath forma de documents junts.',
'texte_erreur_mise_niveau_base' => 'Error de basa de dadas pendent la hicada a niv&egrave;u. L\'imatge <b>@fichier@</b> n\'ei pas passat (article @id_article@).
  Notatz plan aquera refer&eacute;ncia, tornatz ensajar la hicada a
 niv&egrave;u, e verificatz puish que los imatges aparegan
 enq&uuml;&egrave;ra dens los articles.', # MODIF
'texte_erreur_visiteur' => 'Vous avez tent&eacute; de d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.', # NEW
'texte_inc_auth_1' => 'Qu\'&egrave;tz identificat/ada com
   <b>@auth_login@</b>, mes aqueth login n\'existeish pas o plus dens la basa.
  Ensajatz de\'vs', # MODIF
'texte_inc_auth_2' => 'tornar connectar',
'texte_inc_auth_3' => ', apr&egrave;s qu\'auratz quitat eventuaument, puish
  tornat lan&ccedil;ar lo v&ograve;ste navigader.',
'texte_inc_config' => 'Las modificacions h&egrave;itas dens aquestas paginas qu\'influ&eacute;ncian de b&egrave;th pro lo
 foncionament deu v&ograve;ste sit. Que vs\'aconselham de n\'interviene\'i pas tant que non siatz pas
 acostumat/ada au foncionament deu sist&egrave;ma SPIP. <br /><br /><b>
 En generau, que\'s conselha h&ograve;rt
 de deishar la carga d\'aquestas paginas au webm&egrave;stre principau deu v&ograve;ste sit.</b>', # MODIF
'texte_inc_meta_1' => 'Lo sist&egrave;ma qu\'a rescontrat ua error dens l\'escritura deu fichi&egrave;r <code>@fichier@</code>.Volhatz, com administrator/tritz deu sit,', # MODIF
'texte_inc_meta_2' => 'verificar los drets d\'escritura',
'texte_inc_meta_3' => 'dens lo repert&ograve;ri <code>@repertoire@</code>.', # MODIF
'texte_statut_en_cours_redaction' => 'en cors de redaccion',
'texte_statut_poubelle' => 'a la caisha de las d&egrave;ishas',
'texte_statut_propose_evaluation' => 'perpausat per avaloracion',
'texte_statut_publie' => 'publicat en linha',
'texte_statut_refuse' => 'arrefusat',
'titre_ajouter_mot_cle' => 'AJUSTAR UN MOT CLAU:',
'titre_breve_proposee' => 'Br&egrave;va perpausada',
'titre_breve_publiee' => 'Br&egrave;va publicada',
'titre_breve_refusee' => 'Br&egrave;va arrefusada',
'titre_cadre_raccourcis' => 'ACORCIDAS:',
'titre_changer_couleur_interface' => 'Cambiar la color de l\'interf&agrave;cia',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Que podetz administrar aqueste article',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'Ajuda sus aqueth element',
'titre_image_auteur_supprime' => 'Autor suprimit',
'titre_image_redacteur' => 'Redactor shens acc&egrave;s',
'titre_image_redacteur_02' => 'Redactor',
'titre_image_visiteur' => 'Vesitaire',
'titre_joindre_document' => 'J&Oacute;NHER UN DOCUMENT',
'titre_liens_entrants' => 'Los ligams entrants',
'titre_mots_cles' => 'MOTS CLAU',
'titre_probleme_technique' => 'Atencion: un probl&egrave;ma tecnic (servider SQL) qu\'empacha d\'accedir a aquera part deu sit. Merc&eacute;s de la v&ograve;sta indulg&eacute;ncia.',
'titre_publier_document' => 'PUBLICAR UN DOCUMENT DENS AQUERA RUBRICA',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Estadisticas deu sit',
'titre_titre_document' => 'T&iacute;tol deu document:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(article de refer&eacute;ncia)',

// Z
'zbug_balise_b_aval' => '&nbsp;: balisa B cap envath',
'zbug_balise_inexistante' => 'Balise @balise@ mal d&eacute;clar&eacute;e pour @from@', # NEW
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'bloca',
'zbug_boucle_recursive_undef' => 'bloca recursiva non definida', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Camp @champ@ h&ograve;ra bloca',
'zbug_champ_hors_motif' => 'Camp @champ@ en deh&ograve;ra d\'ua bloca de motiu @motif@', # MODIF
'zbug_code' => 'c&ograve;de',
'zbug_critere_inconnu' => 'crit&egrave;ri inconegut @critere@', # MODIF
'zbug_distant_interdit' => 'ext&egrave;rne enebit', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'Doublons sur une table sans clef primaire atomique', # NEW
'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla', # MODIF
'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrader que manca', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorr&egrave;cta', # MODIF
'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
'zbug_erreur_execution_page' => 'error d\'execucion de la pagina', # MODIF
'zbug_erreur_filtre' => 'Error: filtre <b>&laquo; @filtre@ &raquo;</b> non definit', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} que s\'aplica sonque a las blocas (FORUMS) o (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Error(s) dens l\'esqueleta',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => 'Error suber lo sit',
'zbug_inversion_ordre_inexistant' => 'inversion d\'un &ograve;rdre inexistent', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # MODIF
'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorr&egrave;ctes', # MODIF
'zbug_profile' => 'Temps de calcul&nbsp;: @time@', # NEW
'zbug_resultat' => 'resultat',
'zbug_serveur_indefini' => 'servidor SQL indefinit', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Taula SQL &laquo;@table@&raquo; inconeguda',
'zxml_connus_attributs' => 'attributs connus', # NEW
'zxml_de' => 'de', # NEW
'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
'zxml_inconnu_balise' => 'balise inconnue', # NEW
'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
'zxml_inconnu_id' => 'ID inconnu', # NEW
'zxml_mais_de' => 'mais de', # NEW
'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
'zxml_non_fils' => 'n\'est pas un fils de', # NEW
'zxml_nonvide_balise' => 'balise non vide', # NEW
'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
'zxml_survoler' => 'survoler pour voir les corrects', # NEW
'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
'zxml_vide_balise' => 'balise vide', # NEW
'zxml_vu' => 'vu auparavant', # NE
);

?>
